@@ -5,7 +5,6 @@ Please see the LICENSE file for the terms and conditions
 associated with this software.
 '''
 from collections import defaultdict
-import asyncio
 
 import aioredis
 from yapic import json
@@ -14,32 +13,21 @@ from cryptofeed.backends.backend import BackendBookCallback, BackendCallback, Ba
 
 
 class RedisCallback(BackendQueue):
-    def __init__(self, host='127.0.0.1', port=6379, socket=None, key=None, none_to='None', numeric_type=float, writer_interval=0.01, **kwargs):
+    def __init__(self, host='127.0.0.1', port=6379, socket=None, key=None, none_to='None', numeric_type=float, **kwargs):
         """
         setting key lets you override the prefix on the
         key used in redis. The defaults are related to the data
         being stored, i.e. trade, funding, etc
-
-        writer_interval: float
-            the frequency writer sleeps when there is nothing in the queue.
-            0 consumes a lot of CPU, while large interval puts pressure on queue.
         """
         prefix = 'redis://'
         if socket:
             prefix = 'unix://'
 
-        self.redis = aioredis.from_url(f"{prefix}{host}:{port}")
+        self.redis = f"{prefix}{host}:{port}"
         self.key = key if key else self.default_key
         self.numeric_type = numeric_type
         self.none_to = none_to
         self.running = True
-        self.exited = False
-        self.writer_interval = writer_interval
-
-    async def stop(self):
-        self.running = False
-        while not self.exited:
-            await asyncio.sleep(0.1)
 
 
 class RedisZSetCallback(RedisCallback):
@@ -53,54 +41,40 @@ class RedisZSetCallback(RedisCallback):
         self.score_key = score_key
         super().__init__(host=host, port=port, socket=socket, key=key, numeric_type=numeric_type, **kwargs)
 
-    async def write(self, data: dict):
-        score = data[self.score_key]
-        await self.queue.put({'score': score, 'data': data})
-
     async def writer(self):
+        conn = aioredis.from_url(self.redis)
+
         while self.running:
+            async with self.read_queue() as updates:
+                async with conn.pipeline(transaction=False) as pipe:
+                    for update in updates:
+                        pipe = pipe.zadd(f"{self.key}-{update['exchange']}-{update['symbol']}", {json.dumps(update): update[self.score_key]}, nx=True)
+                    await pipe.execute()
 
-            count = self.queue.qsize()
-            if count == 0:
-                await asyncio.sleep(self.writer_interval)
-            elif count > 1:
-                async with self.read_many_queue(count) as updates:
-                    async with self.redis.pipeline(transaction=False) as pipe:
-                        for update in updates:
-                            pipe = pipe.zadd(f"{self.key}-{update['data']['exchange']}-{update['data']['symbol']}", {json.dumps(update['data']): update['score']}, nx=True)
-                        await pipe.execute()
-            else:
-                async with self.read_queue() as update:
-                    await self.redis.zadd(f"{self.key}-{update['data']['exchange']}-{update['data']['symbol']}", {json.dumps(update['data']): update['score']}, nx=True)
-
-        await self.redis.close()
-        await self.redis.connection_pool.disconnect()
-        self.exited = True
+        await conn.close()
+        await conn.connection_pool.disconnect()
 
 
 class RedisStreamCallback(RedisCallback):
-    async def write(self, data: dict):
-        await self.queue.put(data)
-
     async def writer(self):
+        conn = aioredis.from_url(self.redis)
+
         while self.running:
+            async with self.read_queue() as updates:
+                async with conn.pipeline(transaction=False) as pipe:
+                    for update in updates:
+                        if 'delta' in update:
+                            update['delta'] = json.dumps(update['delta'])
+                        elif 'book' in update:
+                            update['book'] = json.dumps(update['book'])
+                        elif 'closed' in update:
+                            update['closed'] = str(update['closed'])
 
-            count = self.queue.qsize()
-            if count == 0:
-                await asyncio.sleep(self.writer_interval)
-            elif count > 1:
-                async with self.read_many_queue(count) as updates:
-                    async with self.redis.pipeline(transaction=False) as pipe:
-                        for update in updates:
-                            pipe = pipe.xadd(f"{self.key}-{update['exchange']}-{update['symbol']}", update)
-                        await pipe.execute()
-            else:
-                async with self.read_queue() as update:
-                    await self.redis.xadd(f"{self.key}-{update['exchange']}-{update['symbol']}", update)
+                        pipe = pipe.xadd(f"{self.key}-{update['exchange']}-{update['symbol']}", update)
+                    await pipe.execute()
 
-        await self.redis.close()
-        await self.redis.connection_pool.disconnect()
-        self.exited = True
+        await conn.close()
+        await conn.connection_pool.disconnect()
 
 
 class TradeRedis(RedisZSetCallback, BackendCallback):
@@ -138,14 +112,6 @@ class BookStream(RedisStreamCallback, BackendBookCallback):
         self.snapshot_count = defaultdict(int)
         super().__init__(*args, **kwargs)
 
-    async def write(self, data: dict):
-        if 'delta' in data:
-            data['delta'] = json.dumps(data['delta'])
-        elif 'book' in data:
-            data['book'] = json.dumps(data['book'])
-
-        await super().write(data)
-
 
 class TickerRedis(RedisZSetCallback, BackendCallback):
     default_key = 'ticker'
@@ -177,7 +143,3 @@ class CandlesRedis(RedisZSetCallback, BackendCallback):
 
 class CandlesStream(RedisStreamCallback, BackendCallback):
     default_key = 'candles'
-
-    async def write(self, data: dict):
-        data['closed'] = str(data['closed'])
-        await super().write(data)
