@@ -69,21 +69,25 @@ class SocketCallback(BackendQueue):
         self.numeric_type = numeric_type
         self.none_to = none_to
         self.key = key if key else self.default_key
+        self.running = True
 
     async def writer(self):
-        while True:
+        while self.running:
             await self.connect()
-            async with self.read_queue() as update:
-                if self.conn_type == 'udp://':
-                    if len(update) > self.mtu:
-                        chunks = wrap(update, self.mtu)
-                        for chunk in chunks:
-                            msg = json.dumps({'type': 'chunked', 'chunks': len(chunks), 'data': chunk}).encode()
-                            self.conn.sendto(msg)
+            async with self.read_queue() as updates:
+                for update in updates:
+                    data = {'type': self.key, 'data': update}
+                    data = json.dumps(data)
+                    if self.conn_type == 'udp://':
+                        if len(update) > self.mtu:
+                            chunks = wrap(update, self.mtu)
+                            for chunk in chunks:
+                                msg = json.dumps({'type': 'chunked', 'chunks': len(chunks), 'data': chunk}).encode()
+                                self.conn.sendto(msg)
+                        else:
+                            self.conn.sendto(update.encode())
                     else:
-                        self.conn.sendto(update.encode())
-                else:
-                    self.conn.write(update.encode())
+                        self.conn.write(update.encode())
 
     async def connect(self):
         if not self.conn:
@@ -96,11 +100,6 @@ class SocketCallback(BackendQueue):
             elif self.conn_type == 'uds://':
                 _, self.conn = await asyncio.open_unix_connection(path=self.addr)
 
-    async def write(self, data: dict):
-        data = {'type': self.key, 'data': data}
-        data = json.dumps(data)
-        await self.queue.put(data)
-
 
 class TradeSocket(SocketCallback, BackendCallback):
     default_key = 'trades'
