@@ -9,6 +9,7 @@ from cryptofeed.defines import FTX as FTX_str, EXX as EXX_str, FMFW as FMFW_str,
 from .bitdotcom import BitDotCom
 from .phemex import Phemex
 from .ascendex import AscendEX
+from .ascendex_futures import AscendEXFutures
 from .bequant import Bequant
 from .binance import Binance
 from .binance_delivery import BinanceDelivery
@@ -17,6 +18,7 @@ from .binance_us import BinanceUS
 from .fmfw import FMFW
 from .bitfinex import Bitfinex
 from .bitflyer import Bitflyer
+from .bitget import Bitget
 from .bithumb import Bithumb
 from .bitmex import Bitmex
 from .bitstamp import Bitstamp
@@ -31,12 +33,14 @@ from .dydx import dYdX
 from .exx import EXX
 from .ftx import FTX
 from .ftx_us import FTXUS
+from .ftx_tr import FTXTR
 from .gateio import Gateio
 from .gemini import Gemini
 from .hitbtc import HitBTC
 from .huobi import Huobi
 from .huobi_dm import HuobiDM
 from .huobi_swap import HuobiSwap
+from .independent_reserve import IndependentReserve
 from .kraken import Kraken
 from .kraken_futures import KrakenFutures
 from .kucoin import KuCoin
@@ -49,6 +53,7 @@ from .upbit import Upbit
 # Maps string name to class name for use with config
 EXCHANGE_MAP = {
     ASCENDEX: AscendEX,
+    ASCENDEX_FUTURES: AscendEXFutures,
     BEQUANT: Bequant,
     BINANCE_DELIVERY: BinanceDelivery,
     BINANCE_FUTURES: BinanceFutures,
@@ -58,6 +63,7 @@ EXCHANGE_MAP = {
     BITDOTCOM: BitDotCom,
     BITFINEX: Bitfinex,
     BITFLYER: Bitflyer,
+    BITGET: Bitget,
     BITHUMB: Bithumb,
     BITMEX: Bitmex,
     BITSTAMP: Bitstamp,
@@ -72,12 +78,14 @@ EXCHANGE_MAP = {
     EXX_str: EXX,
     FTX_str: FTX,
     FTX_US: FTXUS,
+    FTX_TR: FTXTR,
     GATEIO: Gateio,
     GEMINI: Gemini,
     HITBTC: HitBTC,
     HUOBI_DM: HuobiDM,
     HUOBI_SWAP: HuobiSwap,
     HUOBI: Huobi,
+    INDEPENDENT_RESERVE: IndependentReserve,
     KRAKEN_FUTURES: KrakenFutures,
     KRAKEN: Kraken,
     KUCOIN: KuCoin,
