@@ -1,5 +1,5 @@
 '''
-Copyright (C) 2017-2021  Bryant Moscon - bmoscon@gmail.com
+Copyright (C) 2017-2022 Bryant Moscon - bmoscon@gmail.com
 
 Please see the LICENSE file for the terms and conditions
 associated with this software.
@@ -75,12 +75,12 @@ class KrakenRestMixin(RestExchange):
         encoded = (str(payload['nonce']) + postdata).encode('utf8')
         message = urlpath.encode() + hashlib.sha256(encoded).digest()
 
-        signature = hmac.new(base64.b64decode(self.config.key_secret),
+        signature = hmac.new(base64.b64decode(self.key_secret),
                              message, hashlib.sha512)
         sigdigest = base64.b64encode(signature.digest())
 
         headers = {
-            'API-Key': self.config.key_id,
+            'API-Key': self.key_id,
             'API-Sign': sigdigest.decode()
         }
 
