@@ -30,7 +30,7 @@ LOG = logging.getLogger("feedhandler")
 class OKX(Feed, OKXRestMixin):
     id = OKX_str
     websocket_channels = {
-        L2_BOOK: 'books-l2-tbt',
+        L2_BOOK: 'books',
         TRADES: 'trades',
         TICKER: 'tickers',
         FUNDING: 'funding-rate',
@@ -42,7 +42,7 @@ class OKX(Feed, OKXRestMixin):
         WebsocketEndpoint('wss://ws.okx.com:8443/ws/v5/public', channel_filter=(websocket_channels[L2_BOOK], websocket_channels[TRADES], websocket_channels[TICKER], websocket_channels[FUNDING], websocket_channels[OPEN_INTEREST], websocket_channels[LIQUIDATIONS]), options={'compression': None}),
         WebsocketEndpoint('wss://ws.okx.com:8443/ws/v5/private', channel_filter=(websocket_channels[ORDER_INFO],), options={'compression': None}),
     ]
-    rest_endpoints = [RestEndpoint('https://www.okx.com', routes=Routes(['/api/v5/public/instruments?instType=SPOT', '/api/v5/public/instruments?instType=SWAP', '/api/v5/public/instruments?instType=FUTURES', '/api/v5/public/instruments?instType=OPTION&uly=BTC-USD', '/api/v5/public/instruments?instType=OPTION&uly=ETH-USD'], liquidations='/v5/public/liquidation-orders?instType={}&limit=100&state={}&uly={}'))]
+    rest_endpoints = [RestEndpoint('https://www.okx.com', routes=Routes(['/api/v5/public/instruments?instType=SPOT', '/api/v5/public/instruments?instType=SWAP', '/api/v5/public/instruments?instType=FUTURES', '/api/v5/public/instruments?instType=OPTION&uly=BTC-USD', '/api/v5/public/instruments?instType=OPTION&uly=ETH-USD'], liquidations='/api/v5/public/liquidation-orders?instType={}&limit=100&state={}&uly={}'))]
     request_limit = 20
 
     @classmethod
@@ -91,7 +91,7 @@ class OKX(Feed, OKXRestMixin):
 
         while True:
             for pair in pairs:
-                if 'PERP' in pair:
+                if 'SWAP' in pair:
                     instrument_type = 'SWAP'
                     uly = pair.split("-")[0] + "-" + pair.split("-")[1]
                 else:
@@ -112,10 +112,11 @@ class OKX(Feed, OKXRestMixin):
                             self.id,
                             pair,
                             BUY if entry['side'] == 'buy' else SELL,
-                            None,
+                            Decimal(entry['sz']),
                             Decimal(entry['bkPx']),
-                            status,
                             None,
+                            status,
+                            self.timestamp_normalize(int(entry['ts'])),
                             raw=data
                         )
                         await self.callback(LIQUIDATIONS, liq, timestamp)
@@ -229,7 +230,7 @@ class OKX(Feed, OKXRestMixin):
             for update in msg['data']:
                 bids = {Decimal(price): Decimal(amount) for price, amount, *_ in update['bids']}
                 asks = {Decimal(price): Decimal(amount) for price, amount, *_ in update['asks']}
-                self._l2_book[pair] = OrderBook(self.id, pair, max_depth=self.max_depth, checksum_format='OKEX', bids=bids, asks=asks)
+                self._l2_book[pair] = OrderBook(self.id, pair, max_depth=self.max_depth, checksum_format=self.id, bids=bids, asks=asks)
 
                 if self.checksum_validation and self._l2_book[pair].book.checksum() != (update['checksum'] & 0xFFFFFFFF):
                     raise BadChecksum
@@ -342,9 +343,9 @@ class OKX(Feed, OKXRestMixin):
             BUY if msg['data'][0]['side'].lower() == 'buy' else SELL,
             status,
             o_type,
-            Decimal(msg['data'][0]['fillPx']) if msg['data'][0]['fillPx'] else Decimal(0),
-            Decimal(msg['data'][0]['fillSz']) if msg['data'][0]['fillSz'] else Decimal(0),
-            Decimal(msg['data'][0]['sz']) - Decimal(msg['data'][0]['accFillSz']) if msg['data'][0]['accFillSz'] else Decimal(0),
+            Decimal(msg['data'][0]['px']) if msg['data'][0]['px'] else Decimal(msg['data'][0]['avgPx']),
+            Decimal(msg['data'][0]['sz']),
+            Decimal(msg['data'][0]['sz']) - Decimal(msg['data'][0]['accFillSz']) if msg['data'][0]['accFillSz'] else Decimal(msg['data'][0]['sz']),
             self.timestamp_normalize(int(msg['data'][0]['uTime'])),
             raw=msg
         )
@@ -369,17 +370,17 @@ class OKX(Feed, OKXRestMixin):
             else:
                 LOG.warning("%s: Unhandled event %s", self.id, msg)
         elif 'arg' in msg:
-            if 'books-l2-tbt' in msg['arg']['channel']:
+            if self.websocket_channels[L2_BOOK] in msg['arg']['channel']:
                 await self._book(msg, timestamp)
-            elif 'tickers' in msg['arg']['channel']:
+            elif self.websocket_channels[TICKER] in msg['arg']['channel']:
                 await self._ticker(msg, timestamp)
-            elif 'trades' in msg['arg']['channel']:
+            elif self.websocket_channels[TRADES] in msg['arg']['channel']:
                 await self._trade(msg, timestamp)
-            elif 'funding-rate' in msg['arg']['channel']:
+            elif self.websocket_channels[FUNDING] in msg['arg']['channel']:
                 await self._funding(msg, timestamp)
-            elif 'orders' in msg['arg']['channel']:
+            elif self.websocket_channels[ORDER_INFO] in msg['arg']['channel']:
                 await self._order(msg, timestamp)
-            elif 'open-interest' in msg['arg']['channel']:
+            elif self.websocket_channels[OPEN_INTEREST] in msg['arg']['channel']:
                 await self._open_interest(msg, timestamp)
         else:
             LOG.warning("%s: Unhandled message %s", self.id, msg)
@@ -387,6 +388,9 @@ class OKX(Feed, OKXRestMixin):
     async def subscribe(self, connection: AsyncConnection):
         channels = []
         for chan in self.subscription:
+            if chan == LIQUIDATIONS:
+                asyncio.create_task(self._liquidations(self.subscription[chan]))
+                continue
             for pair in self.subscription[chan]:
                 channels.append(self.build_subscription(chan, pair))
 
@@ -428,7 +432,7 @@ class OKX(Feed, OKXRestMixin):
         return instrument_type_map.get(instrument_type, 'MARGIN')
 
     def _get_server_time(self):
-        endpoint = "v5/public/time"
+        endpoint = "public/time"
         response = requests.get(self.api + endpoint)
         if response.status_code == 200:
             return response.json()['data'][0]['ts']
